/*----------------------------------------------------------------------*\
 * args.c								*
 * Command line argument utilities					*
 * UCAR/NCAR/ATD/FOF/RDSG/G. Forrest Cook	12/13/89		*
\*----------------------------------------------------------------------*/

#define TRUE 1
#define FALSE 0
#include <stdio.h>
#include <string.h>

/*----------------------------------------------------------------------*\
 * Search the argv strings for an ocurrence of a "-[char]" arg, if it	*
 * is found, return 1, if it is not found, return 0.			*
\*----------------------------------------------------------------------*/

int get_opt_arg (int argc, char **argv, char argchr)
{
	int i=1;
	char cmpstr[3] = "-?";

	cmpstr[1] = argchr;

	while (i < argc)
	{
		if (!strcmp(cmpstr, argv[i++])) return (1);
	}

	return (0);
}
/*----------------------------------------------------------------------*\
 * Search the argv strings for an ocurrence of a "-[char] integer" arg, *
 * if it is found, set retint to the integer value of the next argument.*
 * Return 1 for success, 0 for failure.					*
\*----------------------------------------------------------------------*/

int get_opt_int_arg (int argc, char **argv, char argchr, int dflt, int *retint)
{
	int i=1, sn;
	char cmpstr[3] = "-?";

	cmpstr[1] = argchr;

	while (i < argc)
	{
		if (!strcmp(cmpstr, argv[i]))
		{
			if (i < argc-1)
			{
				sn = sscanf (argv[i+1], "%d", retint);
				if (sn == 1) return (1);
			}
		}
		i++;
	}

	*retint = dflt;

	return (0);
}

/*----------------------------------------------------------------------*\
 * Search the argv strings for an ocurrence of a "-[char] float" arg, 	*
 * if it is found, set retfloat to the float value of the next argument.*
 * Return 1 for success, 0 for failure.					*
\*----------------------------------------------------------------------*/

int get_opt_float_arg (int argc, char **argv, char argchr, float dflt, float *retfloat)
{
	int i=1, sn;
	char cmpstr[3] = "-?";

	cmpstr[1] = argchr;

	while (i < argc)
	{
		if (!strcmp(cmpstr, argv[i]))
		{
			if (i < argc-1)
			{
				sn = sscanf (argv[i+1], "%f", retfloat);
				if (sn == 1) return (1);
			}
		}
		i++;
	}

	*retfloat = dflt;

	return (0);
}

/*----------------------------------------------------------------------*\
 * Search the argv strings for an ocurrence of a "-[char] string" arg,  *
 * if it is found, set retstr to the string value of the next argument. *
 * Return 1 for success, 0 for failure.					*
\*----------------------------------------------------------------------*/

int get_opt_str_arg (int argc, char **argv, char argchr, char *dflt, char *retstr)
{
	int i=1, sl;
	char cmpstr[3] = "-?";
	cmpstr[1] = argchr;

	while (i < argc)
	{
		if (!strcmp(cmpstr, argv[i]))
		{
			if (i < argc-1)
			{
				sl = strlen (argv[i+1]);
				if (sl)
				{
					strncpy (retstr, argv[i+1], sl);
					retstr[sl] = '\0';
					return (1);
				}
			}
		}
		i++;
	}

	strcpy (retstr, dflt);

	return (0);
}

/*----------------------------------------------------------------------*
 *	Return TRUE if ch is found in the string str			*
 *----------------------------------------------------------------------*/

int arg_find (char *str, char ch)
{
	int i, sl=strlen (str);

	for (i=0; i<sl; i++) if (str[i] == ch) return (TRUE);

	return (FALSE);
}

/*----------------------------------------------------------------------*
 *	Set dest to positive int within str, else set to dflt		*
 *----------------------------------------------------------------------*/

void arg_p_int (char *str, char ch, int *dest, int dflt)
{
	int a, i, st=0, sl=strlen(str);

	*dest = dflt;			/* set default answer */

	for (i=0; i<sl; i++) if (str[i] == ch) break;

	if (++i < sl)			/* make sure #s follow ch */
	{
		while ((a=(int)str[i++]) != '\0')
		{
			if ((a >= '0') && (a <= '9'))
			{
				st = (st*10)+(a-'0');	/* shift and add */
				*dest = st;
			}
			else break;
		}
	}
}

/*----------------------------------------------------------------------*/
/*
 * Convert the argument (num) to an integer if possible, else return dflt.
 */
int get_int_arg (int argc, char **argv, int num, int dflt)
{
	int intarg, conv, noconv=0;

	if (argc > num)
	{
		conv = sscanf (argv[num], "%d", &intarg);
		if (conv != 1) noconv = 1;
	}
	else noconv=1;

	if (noconv) return (dflt);
	else return (intarg);
}

/*----------------------------------------------------------------------*/
/*
 * Convert the argument to a string if possible, else return dflt.
 */
void get_str_arg (int argc, char **argv, int num, char *str, char *dflt)
{
	int conv, noconv=0;

	if (argc > num)
	{
		conv = sscanf (argv[num], "%s", str);
		if (conv != 1) noconv = 1;
	}
	else noconv=1;

	if (noconv) strcpy (str, dflt);
}

/*----------------------------------------------------------------------*/
