/*
 * fwatch.c
 *
 * Periodically watch a file, execute something when the
 * file date changes.  Used to trigger a plotting operation on
 # a data file that periodically updates.
 *
 * G. Forrest Cook
 * version 1.0 Jan 21, 2000
 *
 */

#include <unistd.h>
#include <sys/stat.h>
#include <sys/types.h>
#include <stdio.h>
#include <ctype.h>
#include <errno.h>
#include <string.h>
#include "args.h"

int main (unsigned int argc, char **argv)
{
	int verb;
	int delay;
	int first=1;
	char tfname[120];	/* test file */
	char rfname[120];	/* run file */
	struct stat stbuf;
	time_t last_time;

/*
 * Get -f filename arg and -x execute comd arg.
 */
	verb = get_opt_arg (argc, argv, 'v');
	get_opt_int_arg (argc, argv, 't', 1, &delay);

	if (!get_opt_str_arg (argc, argv, 'f', "", tfname))
	{
	    printf ("\nUsage: fwatch -f file -r \"comd\" -t delay -v(erbose)\n\n");
	    return (1);
	}

	if (!get_opt_str_arg (argc, argv, 'r', "", rfname))
	{
	    printf ("\nUsage: fwatch -f file -r \"comd\" -t delay -v(erbose)\n\n");
	    return (1);
	}

	if (verb)
	{
	    printf ("\nfwatch version 1.0\n\n");
	    printf ("filename: %s\n", tfname);
	    printf ("command:  %s\n", rfname);
	    if (delay > 1) printf ("time delay: %d seconds\n", delay);
	    else printf ("time delay: %d second\n", delay);
	}

	if (stat (tfname, &stbuf) == -1)	/* if file doesn't exist */
	{
	    printf ("\nError accessing file: %s\n\n", tfname);
	    return (1);
	}

#if 0
	/* breaks for long commands */
	if (stat (rfname, &stbuf) == -1)	/* if file doesn't exist */
	{
	    printf ("\nError accessing file: %s\n\n", rfname);
	    return (1);
	}
#endif

	while (1)
	{
	    stat (tfname, &stbuf);	/* get file info */

	    if (first)
	    {
	        first=0;
	        last_time = stbuf.st_ctime;
	    }

	    if (last_time != stbuf.st_ctime)	/* the file time changed */
	    {
	        if (verb) printf ("\nTime Changed: %s\n",ctime(&last_time));
		system (rfname);
	    }

	    sleep (delay);
	    last_time = stbuf.st_ctime;
	}

	return (0);
}

#ifdef DEBUG
printf ("\nTime1:%sTime2:%s %x\n", ctime(&last_time), ctime (&(stbuf.st_ctime)),
printf ("[%x-%x]\n", last_time, stbuf.st_ctime);
printf ("\ntick");
printf ("\nTime:%s\n", ctime(&last_time));
printf ("."); fflush (stdout);
#endif
